# python-certsrv

[![PythonCertsrv Version](https://img.shields.io/pypi/v/python-certsrv?style=for-the-badge)](https://pypi.org/project/python-certsrv/)
[![PythonCertsrv Status](https://img.shields.io/pypi/status/python-certsrv?style=for-the-badge)](https://pypi.org/project/python-certsrv)
[![PythonCertsrv Python Versions](https://img.shields.io/pypi/pyversions/python-certsrv?style=for-the-badge)](https://pypi.org/project/python-certsrv/)
[![PythonCertsrv Release](https://img.shields.io/github/release/degagne/python-certsrv?style=for-the-badge)](https://github.com/degagne/python-certsrv/releases/)
[![PythonCertsrv License](https://img.shields.io/github/license/degagne/python-certsrv?style=for-the-badge)](https://github.com/degagne/python-certsrv/blob/master/LICENSE)

Provide a convenient interface to create and/or retrieve certificates from the Active Directory Certificate Services (ADCS) Web Enrollment service.

## Installation

It's recommended to be installed using [pip](https://pip.pypa.io/en/stable/).

```bash
pip install python-certsrv
```

Releases are listed on the [Releases](https://github.com/degagne/python-certsrv/releases) page.

## Documentation

For documentation, please visit [python-certsrv](https://python-certsrv.readthedocs.io/en/latest/index.html).

## License

`python-certsrv` is licensed under MIT license. See the [LICENSE](https://github.com/degagne/python-certsrv/blob/master/LICENSE) for more information.